/*******************************************************************************
 *     Tablexia	
 * 
 *     Copyright (C) 2013  CZ NIC z.s.p.o. <podpora at nic dot cz>
 * 
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 * 
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 * 
 *     You should have received a copy of the GNU General Public License
 *     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ******************************************************************************/
package cz.nic.tablexia.game.difficulty;


import cz.nic.tablexia.loader.application.ApplicationTextManager;

/**
 * Game difficulty types
 * 
 * @author Matyáš Latner
 */
public enum GameDifficulty {

    EASY    ("gamedifficulty_easy"),
    MEDIUM  ("gamedifficulty_medium"),
    HARD    ("gamedifficulty_hard");

    public static final GameDifficulty DEFAULT_DIFFICULTY = EASY;

    private String descriptionResourceKey;

    private GameDifficulty(String descriptionResourceKey) {
        this.descriptionResourceKey = descriptionResourceKey;
    }

    public String getTextDescription() {
        return ApplicationTextManager.getInstance().getText(getDescriptionResourceKey());
    }

    /**
     * Returns key of description for current difficulty
     * 
     * @return key of description string resource
     */
    public String getDescriptionResourceKey() {
        return descriptionResourceKey;
    }

    /**
     * Returns difficulty for integer value
     * 
     * @param number integer value for difficulty
     * @return difficulty
     */
    public static GameDifficulty getDifficultyForInt(int number) {
        GameDifficulty[] values = GameDifficulty.values();
        if ((number >= 0) && (number < values.length)) {
            return GameDifficulty.values()[number];
        }
        return null;
    }
}
