package cz.nic.tablexia.game.games.robbery;

import java.util.List;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.scenes.scene2d.Stage;

import cz.nic.tablexia.game.games.robbery.assets.RobberyAssets;
import cz.nic.tablexia.game.games.robbery.creature.CreatureRoot;
import cz.nic.tablexia.screen.AbstractTablexiaScreen;
import cz.nic.tablexia.util.Log;

public class DebugScreen extends AbstractTablexiaScreen<Void> {
	
	private enum DebugGroupColors {
        RED(Color.RED),
        GREEN(Color.GREEN),
        BLUE(Color.BLUE),
        YELLOW(Color.YELLOW),
        WHITE(Color.WHITE),
        PINK(Color.PINK),
        CYAN(Color.CYAN),
        LIGHTBLUE(new Color(0.569f, 0.612f, 0.976f, 1f)),
        LIGHTRED(new Color(0.976f, 0.569f, 0.569f, 1f)),
        LIGHTGREEN(new Color(0.569f, 0.976f, 0.631f, 1f)),
        LIGHTPURPLE(new Color(0.969f, 0.569f, 0.976f, 1f));

        Color color;

        private DebugGroupColors(Color color) {
            this.color = color;
        }

        public Color getColor() {
            return color;
        }
    }
	
	@Override
	protected void screenLoaded() {		
		displayAllCreatures(RobberyScreen.getRobberyData().getCreatures(), getStage());
	}
	
	private void displayAllCreatures(List<CreatureRoot> creatures, Stage stage) {
		if (creatures != null && creatures.size() > 0) {				
			float creatureScale 	= 0.5f;
			Texture sizeTexture 	= RobberyScreen.getRobberyTexture(RobberyAssets.CREATURE_BACKGROUND_TEXTURE);
			
			float creatureWidth  	= sizeTexture.getWidth() * creatureScale;
			float creatureHeight 	= sizeTexture.getHeight() * creatureScale;
			
			float borderX 			= (Gdx.graphics.getWidth() / 40);
			float borderY 			= Gdx.graphics.getHeight() / 7;
			
			int creaturesInLine 	= (int)Math.ceil(Double.valueOf(creatures.size()) / 2);
			float xStep				= (Gdx.graphics.getWidth() - (2 * borderX) - (creatureWidth / 2)) / creaturesInLine;
			
			float positionX 		= borderX;
			float positionY 		= Gdx.graphics.getHeight() - (creatureHeight) - borderY;
			
			for (int i = 0; i < creatures.size(); i++) {
				CreatureRoot creatureRoot = creatures.get(i);
				creatureRoot.setScale(creatureScale);
				creatureRoot.setPosition(positionX, positionY);
				int groupNumber = creatureRoot.getGroupNumber();
				if (groupNumber >= 0) {            	
					creatureRoot.highliteWithColor(DebugGroupColors.values()[groupNumber].getColor());
				}
				
				positionX = positionX + xStep;
				if ((i + 1) % creaturesInLine == 0) {
					positionX = borderX;
					positionY = borderY;
				}
				
				stage.addActor(creatureRoot);
			}
		} else {
			Log.info(getClass(), "No creatures to display!");
		}
    }

}
