package cz.nic.tablexia.loader;

import com.badlogic.gdx.assets.AssetManager;
import com.badlogic.gdx.assets.loaders.FileHandleResolver;
import com.badlogic.gdx.assets.loaders.resolvers.ExternalFileHandleResolver;
import com.badlogic.gdx.assets.loaders.resolvers.InternalFileHandleResolver;

import cz.nic.tablexia.util.Log;

public class TablexiaAssetManager extends AssetManager {

    public enum StorageType {

        INTERNAL("", new InternalFileHandleResolver()),
        EXTERNAL(".tablexia/", new ExternalFileHandleResolver());

        private String storagePath;
        private FileHandleResolver resolver;

        StorageType(String storagePath, FileHandleResolver resolver) {
            this.storagePath = storagePath;
            this.resolver = resolver;
        }

        public String getStoragePath() {
            return storagePath;
        }

        public FileHandleResolver getResolver() {
            return resolver;
        }
    }

    private final StorageType   storageType;

    protected TablexiaAssetManager(StorageType storageType) {
        super(storageType.getResolver());
        this.storageType = storageType;
    }

    public <T> void loadAsset(String assetFileName, Class<T> clazz) {
        if (assetFileName != null) {
            load(storageType.getStoragePath() + assetFileName, clazz);
        } else {
            Log.err(getClass(), "Asset file for name: " + assetFileName + " was not found!");
        }
    }

    public <T> T getAsset(String assetName, Class<T> clazz) {
        return get(storageType.getStoragePath() + assetName, clazz);
    }
}
