package cz.nic.tablexia.loader.zip;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.files.FileHandle;
import com.badlogic.gdx.utils.I18NBundle;
import com.badlogic.gdx.utils.async.AsyncTask;

import java.io.BufferedInputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Locale;
import java.util.zip.ZipEntry;
import java.util.zip.ZipInputStream;

import cz.nic.tablexia.loader.IApplicationLoader;
import cz.nic.tablexia.loader.TablexiaAssetManager;
import cz.nic.tablexia.loader.TablexiaDataManager;

/**
 * Zip assets content loader
 *
 * @author Matyáš Latner
 *
 */
public class ZipAssetLoader extends TablexiaDataManager<I18NBundle> implements IApplicationLoader {

    public static final TablexiaAssetManager.StorageType ZIP_FILES_STORAGE_TYPE = TablexiaAssetManager.StorageType.INTERNAL;
    public static final String                           ZIP_FILE_EXTENSION     = ".zip";
    public static final String                           COMMON_ZIP_FILE_NAME   = "common";

    private static class ZipAssetLoaderTask implements AsyncTask<I18NBundle> {

		private Locale locale;

		public ZipAssetLoaderTask(Locale locale) {
			this.locale = locale;
		}

		@Override
		public I18NBundle call() throws Exception {
            String commonZipFile = COMMON_ZIP_FILE_NAME + ZIP_FILE_EXTENSION;
            String localisedZipFile = locale.getLanguage() + ZIP_FILE_EXTENSION;

            String extractDestinationDirectory = Gdx.files.getExternalStoragePath() + TablexiaAssetManager.StorageType.EXTERNAL.getStoragePath();

            unzip(ZIP_FILES_STORAGE_TYPE.getResolver().resolve(ZIP_FILES_STORAGE_TYPE.getStoragePath() + commonZipFile), extractDestinationDirectory);
            unzip(ZIP_FILES_STORAGE_TYPE.getResolver().resolve(ZIP_FILES_STORAGE_TYPE.getStoragePath() + localisedZipFile), extractDestinationDirectory);

			return null;
		}

        public static void unzip(FileHandle zipFile, String extractDestinationDirectory) throws IOException {
            ZipInputStream zipInputStream = new ZipInputStream(new BufferedInputStream(zipFile.read()));
            try {
                ZipEntry zipEntry;
                int count;
                byte[] buffer = new byte[8192];
                while ((zipEntry = zipInputStream.getNextEntry()) != null) {

                    if (zipEntry.isDirectory()) {
                        continue;
                    }

                    File file = new File(extractDestinationDirectory, zipEntry.getName());

                    File dir = zipEntry.isDirectory() ? file : file.getParentFile();
                    if (!dir.isDirectory() && !dir.mkdirs()) {
                        throw new FileNotFoundException("Failed to ensure directory: " + dir.getAbsolutePath());
                    }
                    if (zipEntry.isDirectory()) {
                        continue;
                    }
                    FileOutputStream fout = new FileOutputStream(file);
                    try {
                        while ((count = zipInputStream.read(buffer)) != -1) {
                            fout.write(buffer, 0, count);
                        }
                    } finally {
                        fout.close();
                    }
                }
            } finally {
                zipInputStream.close();
            }
        }
	}
	
	public void load(Locale locale) {
        setAsyncTask(new ZipAssetLoaderTask(locale));
	}
	
}