package cz.nic.tablexia.menu;

import com.badlogic.gdx.graphics.g2d.Batch;
import com.badlogic.gdx.scenes.scene2d.Actor;
import com.badlogic.gdx.scenes.scene2d.Group;
import com.badlogic.gdx.scenes.scene2d.InputEvent;
import com.badlogic.gdx.scenes.scene2d.utils.ClickListener;

/**
 * MainMenu container
 *
 * @author Matyáš Latner
 */
public class MainMenuContainer extends Group {

    private static final float      MAIN_MENU_WIDTH_RATIO        = 2f/7;

    private final MainMenu          mainMenu;
    private final Group             screenDimmerLayer;
    private final Actor             screenDimmer;

    public MainMenuContainer(float width, float height) {
        setBounds(0, 0, width, height);

        screenDimmerLayer = new Group();
        addActor(screenDimmerLayer);

        mainMenu = new MainMenu(width * MAIN_MENU_WIDTH_RATIO, height);
        mainMenu.initMenuItems();
        addActor(mainMenu);

        screenDimmer = new MainMenuDimmer(width, height);
        screenDimmer.addListener(new ClickListener() {

            @Override
            public void clicked(InputEvent event, float x, float y) {
                mainMenu.closeMenu(true);
            }
        });
    }

    @Override
    public void draw(Batch batch, float parentAlpha) {
        super.draw(batch, parentAlpha);
        if (mainMenu.getMenuOpenPercentage() == 0) {
            if (screenDimmer.getStage() != null) {
                screenDimmer.remove();
            }
        } else {
            if (screenDimmer.getStage() == null) {
                screenDimmerLayer.addActor(screenDimmer);
            }
            screenDimmer.setColor(screenDimmer.getColor().r, screenDimmer.getColor().g, screenDimmer.getColor().b, mainMenu.getMenuOpenPercentage());
        }
    }

    public void openMainMenu(boolean animated) {
        mainMenu.openMenu(animated);
    }
}
