package cz.nic.tablexia.screen.gamemenu;

import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.scenes.scene2d.Touchable;
import com.badlogic.gdx.scenes.scene2d.ui.Image;

import net.engio.mbassy.listener.Handler;

import java.util.List;

import cz.nic.tablexia.TablexiaSettings;
import cz.nic.tablexia.bus.ApplicationBus;
import cz.nic.tablexia.game.GameDefinition;
import cz.nic.tablexia.screen.AbstractTablexiaScreen;
import cz.nic.tablexia.screen.gamemenu.pages.GameMenuPage;
import cz.nic.tablexia.screen.gamemenu.pages.OfficeMenuPage;
import cz.nic.tablexia.util.ui.ViewPager;

public class GameMenuScreen extends AbstractTablexiaScreen<Void> {

    private ViewPager vp;

    @Override
    protected void prepareScreenTextureAssetNames(List<String> textureFileNames) {
        super.prepareScreenTextureAssetNames(textureFileNames);
        textureFileNames.addAll(GameMenuAssets.textures);
    }

    @Override
    protected void screenLoaded() {
        getStage().setDebugAll(TablexiaSettings.getInstance().isShowBoundingBoxes());
        vp = new ViewPager();
        vp.addPage(new OfficeMenuPage(this));

        for (GameDefinition gd : GameDefinition.getActiveGames()) {
            vp.addPage(new GameMenuPage(this, gd));
        }

        vp.setSize(getStage().getWidth(), getStage().getHeight());
        getStage().addActor(vp);

        Image im = new Image(getTexture(GameMenuAssets.VIGNETTE));
        im.setTouchable(Touchable.disabled);
        im.setSize(getStage().getWidth(), getStage().getHeight());
        getStage().addActor(im);

        ApplicationBus.getInstance().subscribe(this);
    }

    @Handler
    public void handleShowStreet(OfficeMenuPage.ShowStreetEvent message) {
        vp.scrollToPage(1);
    }

    @Override
    public Texture getTexture(String textureName) {
        Texture texture = super.getTexture(textureName);
        texture.setFilter(Texture.TextureFilter.Linear, Texture.TextureFilter.Linear);
        return texture;
    }
}
