package cz.nic.tablexia.screen.halloffame;

import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.Sprite;
import com.badlogic.gdx.scenes.scene2d.Group;
import com.badlogic.gdx.scenes.scene2d.InputEvent;
import com.badlogic.gdx.scenes.scene2d.ui.HorizontalGroup;
import com.badlogic.gdx.scenes.scene2d.ui.Image;
import com.badlogic.gdx.scenes.scene2d.ui.ScrollPane;
import com.badlogic.gdx.scenes.scene2d.ui.Stack;
import com.badlogic.gdx.scenes.scene2d.utils.ClickListener;
import com.badlogic.gdx.scenes.scene2d.utils.SpriteDrawable;

import java.util.List;

import cz.nic.tablexia.TablexiaSettings;
import cz.nic.tablexia.screen.AbstractTablexiaScreen;
import cz.nic.tablexia.screen.halloffame.assets.HallOfFameAssets;
import cz.nic.tablexia.screen.halloffame.helper.TrophyHelper;
import cz.nic.tablexia.util.Log;
import cz.nic.tablexia.util.ui.dialog.ImageDialog;
import cz.nic.tablexia.util.ui.dialog.SingleButtonDialog;
import cz.nic.tablexia.util.ui.dialog.TablexiaDialog;
import cz.nic.tablexia.util.ui.dialog.TwoButtonDialog;
import cz.nic.tablexia.util.ui.dialog.text.DialogTextContent;

public class HallOfFameScreen extends AbstractTablexiaScreen<Void> {

    private static enum TrophyHeapAssets {
        HALLOFFAME_TROPHYHEAP_00(HallOfFameAssets.HALL_OF_FAME_TROPHY_HEAP_00, 0), //
        HALLOFFAME_TROPHYHEAP_01(HallOfFameAssets.HALL_OF_FAME_TROPHY_HEAP_01, 1), //
        HALLOFFAME_TROPHYHEAP_02(HallOfFameAssets.HALL_OF_FAME_TROPHY_HEAP_02, 2), //
        HALLOFFAME_TROPHYHEAP_03(HallOfFameAssets.HALL_OF_FAME_TROPHY_HEAP_03, 3), //
        HALLOFFAME_TROPHYHEAP_04(HallOfFameAssets.HALL_OF_FAME_TROPHY_HEAP_04, 4), //
        HALLOFFAME_TROPHYHEAP_05(HallOfFameAssets.HALL_OF_FAME_TROPHY_HEAP_05, 5), //
        HALLOFFAME_TROPHYHEAP_06(HallOfFameAssets.HALL_OF_FAME_TROPHY_HEAP_06, 6), //
        HALLOFFAME_TROPHYHEAP_07(HallOfFameAssets.HALL_OF_FAME_TROPHY_HEAP_07, 7), //
        HALLOFFAME_TROPHYHEAP_08(HallOfFameAssets.HALL_OF_FAME_TROPHY_HEAP_08, 8), //
        HALLOFFAME_TROPHYHEAP_09(HallOfFameAssets.HALL_OF_FAME_TROPHY_HEAP_09, 9), //
        HALLOFFAME_TROPHYHEAP_10(HallOfFameAssets.HALL_OF_FAME_TROPHY_HEAP_10, 10), //
        HALLOFFAME_TROPHYHEAP_15(HallOfFameAssets.HALL_OF_FAME_TROPHY_HEAP_15, 15), //
        HALLOFFAME_TROPHYHEAP_20(HallOfFameAssets.HALL_OF_FAME_TROPHY_HEAP_20, 20), //
        HALLOFFAME_TROPHYHEAP_30(HallOfFameAssets.HALL_OF_FAME_TROPHY_HEAP_30, 30), //
        HALLOFFAME_TROPHYHEAP_35(HallOfFameAssets.HALL_OF_FAME_TROPHY_HEAP_35, 35), //
        HALLOFFAME_TROPHYHEAP_40(HallOfFameAssets.HALL_OF_FAME_TROPHY_HEAP_40, 40), //
        HALLOFFAME_TROPHYHEAP_50(HallOfFameAssets.HALL_OF_FAME_TROPHY_HEAP_50, 50), //
        HALLOFFAME_TROPHYHEAP_60(HallOfFameAssets.HALL_OF_FAME_TROPHY_HEAP_60, 60);

        private String trophyHeapAsset;
        private int starCount;

        private TrophyHeapAssets(String trophyHeapAsset, int starCount) {
            this.trophyHeapAsset = trophyHeapAsset;
            this.starCount = starCount;
        }

        public String getTrophyHeapAssetName() {
            return trophyHeapAsset;
        }

        public int getStarCount() {
            return starCount;
        }

        public static String getTrophyHeapAssetNameForStarCount(int starCount) {
            for (int i = TrophyHeapAssets.values().length - 1; i >= 0; i--) {
                TrophyHeapAssets trophyHeapAssets = TrophyHeapAssets.values()[i];
                if (starCount >= trophyHeapAssets.getStarCount()) {
                    return trophyHeapAssets.getTrophyHeapAssetName();
                }
            }
            return TrophyHeapAssets.values()[0].getTrophyHeapAssetName();
        }
    }
    private static final int     BACKGROUND_TILE_REPEAT_COUNT = 37;

    private Stack contentStack;
    private HorizontalGroup backgroundGroup;
    private Group foregroundGroup;
    private TrophyHelper trophyHelper;

    @Override
    protected void screenLoaded() {
        contentStack = new Stack();
        contentStack.setHeight(getStage().getHeight());
        prepareBackgroundLayer();
        prepareForegroundLayer();

        contentStack.addActor(backgroundGroup);
        contentStack.addActor(foregroundGroup);
        contentStack.setDebug(TablexiaSettings.getInstance().isShowBoundingBoxes());

        ScrollPane scrollPane = new ScrollPane(contentStack);
        scrollPane.setScrollingDisabled(false, true);
        scrollPane.setSize(getStage().getWidth(), getStage().getHeight());

        getStage().addActor(scrollPane);
    }



    private void prepareBackgroundLayer(){
        backgroundGroup = new HorizontalGroup();
        backgroundGroup.setHeight(getStage().getHeight());

        Texture textureDoor = getTexture(HallOfFameAssets.HALL_OF_FAME_DOOR);
        Image imgDoor = new Image(textureDoor);
        imgDoor.setHeight(getStage().getHeight());
        backgroundGroup.addActor(imgDoor);

        Texture textureTile = getTexture(HallOfFameAssets.HALL_OF_FAME_BACKGROUND_TILE);

        for (int i = 0; i < BACKGROUND_TILE_REPEAT_COUNT; i++) {
            Image imgBackground = new Image(textureTile);
            imgBackground.setHeight(getStage().getHeight());

            backgroundGroup.addActor(imgBackground);
        }

    }

    private void prepareDoorButton(){
        final Texture textureDoorButton = getTexture(HallOfFameAssets.HALL_OF_FAME_DOOR_BUTTON_UNPRESSED);
        final Image imgDoorButton = new Image(textureDoorButton);
        imgDoorButton.setHeight(getStage().getHeight());

        imgDoorButton.addListener(new ClickListener() {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                Texture textureDoor = getTexture(HallOfFameAssets.HALL_OF_FAME_DOOR_BUTTON_PRESSED);
                imgDoorButton.setDrawable(new SpriteDrawable(new Sprite(textureDoor)));
                //TODO add action for leaving to main menu
            }
        });
        foregroundGroup.addActor(imgDoorButton);

    }

    private void prepareForegroundLayer(){
        foregroundGroup = new Group();
        foregroundGroup.setHeight(getStage().getHeight());

        prepareDoorButton();
    }

    @Override
    protected void prepareScreenTextureAssetNames(List<String> texturesFileNames) {
        //Door and background
        texturesFileNames.add(HallOfFameAssets.HALL_OF_FAME_DOOR);
        texturesFileNames.add(HallOfFameAssets.HALL_OF_FAME_BACKGROUND_TILE);
        texturesFileNames.add(HallOfFameAssets.HALL_OF_FAME_DOOR_BUTTON_PRESSED);
        texturesFileNames.add(HallOfFameAssets.HALL_OF_FAME_DOOR_BUTTON_UNPRESSED);

        //Trophy heaps
        for(TrophyHeapAssets asset: TrophyHeapAssets.values()){
            texturesFileNames.add(asset.getTrophyHeapAssetName());
        }

        //Trophies

    }

}
