package cz.nic.tablexia.screen.viewport;

import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.scenes.scene2d.InputEvent;
import com.badlogic.gdx.scenes.scene2d.InputListener;
import com.badlogic.gdx.scenes.scene2d.ui.Image;

import java.util.List;

import cz.nic.tablexia.TablexiaSettings;
import cz.nic.tablexia.screen.AbstractTablexiaScreen;
import cz.nic.tablexia.util.Log;

/**
 * Created by lhoracek on 4/13/15.
 */
public class ViewportDebugScreen extends AbstractTablexiaScreen<Void> {

    private static final String BASE = "screen/debug/";

    @Override
    protected void prepareScreenTextureAssetNames(List<String> textureFileNames) {
        textureFileNames.add(BASE + "red.png");
        textureFileNames.add(BASE + "blue.png");
        textureFileNames.add(BASE + "yellow.png");
        textureFileNames.add(BASE + "pink.png");
        textureFileNames.add(BASE + "black.png");
        textureFileNames.add(BASE + "checker.png");
        textureFileNames.add(BASE + "point.png");
    }

    @Override
    protected void screenLoaded() {
        getStage().setDebugAll(true);

        Image large = new Image(getTexture("yellow.png"));
        large.setSize(TablexiaSettings.getWorldWidth(), TablexiaSettings.getMinWorldHeight() * 2);
        large.setPosition(0, TablexiaSettings.getMinWorldHeight() / -2.0f);
        getStage().addActor(large);


        Image widescreen = new Image(getTexture("red.png"));
        widescreen.setSize(1000, TablexiaSettings.getMinWorldHeight());
        widescreen.setPosition(0,0);
        getStage().addActor(widescreen);

        int size = 10;
        for (int i = 0; i < size; i++) {
            for (int j = 0; j < size; j++) {
                Texture checker = getTexture("checker.png");
                Image check = new Image(checker);
                check.setPosition(500 - (check.getWidth() * size / 2) + (i * check.getWidth()), TablexiaSettings.getMinWorldHeight() / 2 - (check.getWidth() * size / 2) + (j * check.getWidth()));
                getStage().addActor(check);
            }
        }

        getStage().addListener(new InputListener() {
            Image point;

            @Override
            public boolean touchDown(InputEvent event, float x, float y, int pointer, int button) {
                Log.debug(getClass(), "Touchdown");
                point = new Image(getTexture("point.png"));
                getStage().addActor(point);
                point.setPosition(x - point.getWidth() / 2, y - point.getHeight() / 2);
                return true;
            }


            @Override
            public void touchDragged(InputEvent event, float x, float y, int pointer) {
                if(point != null) {
                    point.setPosition(x - point.getWidth() / 2, y - point.getHeight() / 2);
                    Log.debug(getClass(), "Touch coords " + (x - point.getWidth() / 2) + ":" + ( y - point.getHeight() / 2));
                }
            }

            @Override
            public void touchUp(InputEvent event, float x, float y, int pointer, int button) {
                if(point != null) {
                    Log.debug(getClass(), "Liftoff");
                    point.remove();
                    point = null;
                }
            }
        });
        // TODO
    }

    @Override
    public Texture getTexture(String textureName) {
        Texture texture = super.getTexture(BASE + textureName);
        texture.setFilter(Texture.TextureFilter.Linear, Texture.TextureFilter.Linear);
        return texture;
    }

}
