package cz.nic.tablexia.util.ui;

import com.badlogic.gdx.math.MathUtils;
import com.badlogic.gdx.scenes.scene2d.Actor;
import com.badlogic.gdx.scenes.scene2d.ui.Cell;
import com.badlogic.gdx.scenes.scene2d.ui.ScrollPane;
import com.badlogic.gdx.scenes.scene2d.ui.Skin;
import com.badlogic.gdx.scenes.scene2d.ui.Table;
import com.badlogic.gdx.utils.Array;

/**
 * Created by lhoracek on 3/4/15.
 */
public class ViewPager extends ScrollPane {

    private boolean wasPanDragFling = false;
    private float lastX;
    private Table content;

    public ViewPager() {
        super(null);
        setup();
    }

    public ViewPager(Skin skin) {
        super(null, skin);
        setup();
    }

    public ViewPager(Skin skin, String styleName) {
        super(null, skin, styleName);
        setup();
    }

    public ViewPager(Actor widget, ScrollPane.ScrollPaneStyle style) {
        super(null, style);
        setup();
    }

    private void setup() {
        content = new Table();
        super.setWidget(content);
        content.setSize(100,100);
        content.defaults().space(0);
        //setClamp(false);
        //setScrollingDisabled(false, true);
        setFlingTime(0.1f);
    }

    @Override
    public void setSize(float width, float height) {
        super.setSize(width, height);
        if (content != null) {
            for (Actor a : content.getChildren()) {
                a.setSize(width, height);
            }
        }
    }

    public void addPages(Actor... pages) {
        for (Actor page : pages) {
            content.add(page).expandY().fillY();
        }
    }

    public void addPage(Actor page) {
        content.add(page).expandY().fillY();
    }

    @Override
    public void act(float delta) {
        if (wasPanDragFling && !isPanning() && !isDragging() && !isFlinging()) {
            wasPanDragFling = false;
            scrollToPage();
        } else {
            if (isPanning() || isDragging() || isFlinging()) {
                wasPanDragFling = true;
            }
        }


        if (lastX != getWidget().getX()) {
            float scrollX = -getWidget().getX();
            Array<Actor> pages = content.getChildren();
            float pageX = 0;
            float pageWidth = 0;

            if (pages.size > 0) {
                for (Actor a : pages) {
                    pageX = a.getX();
                    pageWidth = a.getWidth();
                    if (scrollX > pageX && scrollX < (pageX + pageWidth)) {
                        if (a instanceof ScrollListener) {
                            ScrollListener sl = (ScrollListener) a;
                            sl.onScroll(-(scrollX - pageX));
                        }
                    } else if (scrollX < (pageX) && (scrollX + pageWidth) > pageX) {
                        if (a instanceof ScrollListener) {
                            ScrollListener sl = (ScrollListener) a;
                            sl.onScroll(pageX - scrollX);
                        }
                    }
                    if (pageX == scrollX) {
                        if (a instanceof ScrollListener) {
                            ScrollListener sl = (ScrollListener) a;
                            sl.onScrolledToPage();
                        }
                    }
                }
            }
        }
        lastX = getWidget().getX();
        super.act(delta);
    }


    @Override
    @Deprecated
    public void setWidget(Actor widget) {
        super.setWidget(widget);
    }

    @Override
    public void setWidth(float width) {
        super.setWidth(width);
        if (content != null) {
            for (Cell cell : content.getCells()) {
                cell.width(width);
            }
            content.invalidate();
        }
    }

    /**
     * Smooth scroll to child with given index
     *
     * @param page
     */
    public void scrollToPage(int page) {
        // TODO cleanup
        if (content.getChildren().size <= page) {
            throw new IllegalArgumentException("Page index " + page + " out of bounds");
        }
        final float width = getWidth();
        final float maxX = getMaxX();

        float pageX = 0;
        float pageWidth = 0;
        if (content.getChildren().size > 0) {
            for (int i = 0; i <= page; i++) {
                Actor a = content.getChildren().get(i);
                pageX = a.getX();
                pageWidth = a.getWidth();
            }
            setScrollX(MathUtils.clamp(pageX - (width - pageWidth) / 2, 0, maxX));
        }
    }

    private void scrollToPage() {
        final float width = getWidth();
        final float scrollX = getScrollX();
        final float maxX = getMaxX();

        if (scrollX >= maxX || scrollX <= 0) return;

        Array<Actor> pages = content.getChildren();
        float pageX = 0;
        float pageWidth = 0;
        if (pages.size > 0) {
            for (Actor a : pages) {
                pageX = a.getX();
                pageWidth = a.getWidth();
                if (scrollX < (pageX + pageWidth * 0.5)) {
                    break;
                }
            }
            setScrollX(MathUtils.clamp(pageX - (width - pageWidth) / 2, 0, maxX));
        }
    }

    public static interface ScrollListener {
        public void onScroll(float offset);

        public void onScrolledToPage();
    }
}
