package cz.nic.tablexia.util.ui.dialog;

import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.graphics.g2d.NinePatch;
import com.badlogic.gdx.scenes.scene2d.ui.TextButton;
import com.badlogic.gdx.scenes.scene2d.utils.ClickListener;
import com.badlogic.gdx.scenes.scene2d.utils.NinePatchDrawable;

import cz.nic.tablexia.loader.application.ApplicationFontManager;
import cz.nic.tablexia.util.ui.dialog.text.DialogTextContent;

/**
 * Created by Václav Tarantík on 9.4.15.
 */
public abstract class AbstractButtonDialog extends TextDialog {

    private static final Color DEFAULT_BUTTON_TEXT_COLOR = Color.BLACK;
    private static final String DEFAULT_BUTTON_TEXT_FONT = ApplicationFontManager.APPLICATION_DEFAULT_FONT_REGULAR;

    private static final String BTN_DISABLED_ATLAS_NAME = "tablexiabutton_disabled";
    private static final float BUTTON_WIDTH_RATIO_TO_DIALOG_WIDTH = 0.27f;
    private static final float BUTTON_HEIGHT_RATIO = 0.5f;

    private static final String BTN_DRAWABLE_PRESSED_ENDING = "_pressed";
    private static final String BTN_DRAWABLE_UNPRESSED_ENDING = "_unpressed";

    public AbstractButtonDialog(float x, float y, float width, float height, BackGroundType backGroundType, DialogTextContent dialogTextContent) {
        super(x, y, width, height, backGroundType,dialogTextContent);
    }

    public void createButton(ButtonType buttonType, String buttonText, ClickListener clickListener){
        if(buttonType!=null){

            NinePatch up = buttonAtlas.createPatch(buttonType.getButtonResourceName()+BTN_DRAWABLE_UNPRESSED_ENDING);
            NinePatchDrawable npdUp = new NinePatchDrawable(up);

            NinePatch down = buttonAtlas.createPatch(buttonType.getButtonResourceName()+BTN_DRAWABLE_PRESSED_ENDING);
            NinePatchDrawable npdDown = new NinePatchDrawable(down);

            NinePatch dis = buttonAtlas.createPatch(BTN_DISABLED_ATLAS_NAME);
            NinePatchDrawable npdDis = new NinePatchDrawable(dis);

            TextButton.TextButtonStyle textButtonStyle = new TextButton.TextButtonStyle(npdUp, npdDown, npdDis, ApplicationFontManager.getInstance().getFont(DEFAULT_BUTTON_TEXT_FONT));
            textButtonStyle.fontColor = DEFAULT_BUTTON_TEXT_COLOR;
            TextButton textButton = new TextButton(buttonText, textButtonStyle);

            textButton.addListener(clickListener);

            float buttonWidth = getWidth() * BUTTON_WIDTH_RATIO_TO_DIALOG_WIDTH;
            float buttonHeight = buttonWidth * BUTTON_HEIGHT_RATIO;

            button(textButton);
            getButtonTable().getCell(textButton).width(buttonWidth).height(buttonHeight).spaceLeft(buttonWidth / 3);

        }else{
            throw new IllegalArgumentException("Invalid dialog type. Buttons not supported for this type.");
        }

    }
}
