package cz.nic.tablexia.desktop;

import com.badlogic.gdx.Files;
import com.badlogic.gdx.backends.lwjgl.LwjglApplication;
import com.badlogic.gdx.backends.lwjgl.LwjglApplicationConfiguration;
import com.jcabi.manifests.Manifests;

import java.util.Locale;

import cz.nic.tablexia.Tablexia;
import cz.nic.tablexia.TablexiaSettings;

public class DesktopLauncher {

    private static final String BUILD_VARIANT_MANIFEST_ATTRIBUTE     = "Build-Type";
    private static final String VERSION_NAME_MANIFEST_ATTRIBUTE      = "Version-Name";

    private static final String DESKTOP_ICON_PATH                    = "icon/";
    private static final String DESKTOP_ICON_16                      = DESKTOP_ICON_PATH + "desktop_icon_16.png";
    private static final String DESKTOP_ICON_32                      = DESKTOP_ICON_PATH + "desktop_icon_32.png";
    private static final String DESKTOP_ICON_128                     = DESKTOP_ICON_PATH + "desktop_icon_128.png";
    private static final String DESKTOP_ICON_DEBUG_16                = DESKTOP_ICON_PATH + "desktop_icon_debug_16.png";
    private static final String DESKTOP_ICON_DEBUG_32                = DESKTOP_ICON_PATH + "desktop_icon_debug_32.png";
    private static final String DESKTOP_ICON_DEBUG_128               = DESKTOP_ICON_PATH + "desktop_icon_debug_128.png";
    private static final String DESKTOP_ICON_DEVEL_16                = DESKTOP_ICON_PATH + "desktop_icon_devel_16.png";
    private static final String DESKTOP_ICON_DEVEL_32                = DESKTOP_ICON_PATH + "desktop_icon_devel_32.png";
    private static final String DESKTOP_ICON_DEVEL_128               = DESKTOP_ICON_PATH + "desktop_icon_devel_128.png";

    public static void main(String[] arg) {

        String buildType = loadAttributeFromManifest(BUILD_VARIANT_MANIFEST_ATTRIBUTE);
        String versionName = loadAttributeFromManifest(VERSION_NAME_MANIFEST_ATTRIBUTE);

	    LwjglApplicationConfiguration config = new LwjglApplicationConfiguration();
	    config.resizable = buildType == null || buildType.equals(TablexiaSettings.BuildType.DEVEL.getKey());
	    config.width = 1280;
	    config.height = 800;

        if (buildType == null || buildType.equals(TablexiaSettings.BuildType.DEVEL.getKey())) {
            config.addIcon(DESKTOP_ICON_DEVEL_16, Files.FileType.Internal);
            config.addIcon(DESKTOP_ICON_DEVEL_32, Files.FileType.Internal);
            config.addIcon(DESKTOP_ICON_DEVEL_128, Files.FileType.Internal);
        } else if (buildType.equals(TablexiaSettings.BuildType.DEBUG.getKey())) {
            config.addIcon(DESKTOP_ICON_DEBUG_16, Files.FileType.Internal);
            config.addIcon(DESKTOP_ICON_DEBUG_32, Files.FileType.Internal);
            config.addIcon(DESKTOP_ICON_DEBUG_128, Files.FileType.Internal);
        } else if (buildType.equals(TablexiaSettings.BuildType.RELEASE.getKey())) {
            config.addIcon(DESKTOP_ICON_16, Files.FileType.Internal);
            config.addIcon(DESKTOP_ICON_32, Files.FileType.Internal);
            config.addIcon(DESKTOP_ICON_128, Files.FileType.Internal);
        }

	    new LwjglApplication(new Tablexia(buildType, Locale.getDefault(), versionName, true), config);
    }

    private static String loadAttributeFromManifest(String attributeName) {
        if (Manifests.exists(attributeName)) {
            return Manifests.read(attributeName);
        }
        return null;
    }
}
